<h1 align="center">OpenGeode-IO<sup><i>by Geode-solutions</i></sup></h1>
<h3 align="center">Input/Output formats for OpenGeode</h3>

<p align="center">
  <img src="https://github.com/Geode-solutions/OpenGeode-IO/workflows/CI/badge.svg" alt="Build Status">
  <img src="https://github.com/Geode-solutions/OpenGeode-IO/workflows/CD/badge.svg" alt="Deploy Status">
  <img src="https://codecov.io/gh/Geode-solutions/OpenGeode-IO/branch/master/graph/badge.svg" alt="Coverage Status">
  <img src="https://img.shields.io/github/release/Geode-solutions/OpenGeode-IO.svg" alt="Version">
  <img src="https://img.shields.io/pypi/v/opengeode-io" alt="PyPI" >
</p>

<p align="center">
  <img src="https://img.shields.io/static/v1?label=Windows&logo=windows&logoColor=white&message=support&color=success" alt="Windows support">
  <img src="https://img.shields.io/static/v1?label=Ubuntu&logo=Ubuntu&logoColor=white&message=support&color=success" alt="Ubuntu support">
  <img src="https://img.shields.io/static/v1?label=Red%20Hat&logo=Red-Hat&logoColor=white&message=support&color=success" alt="Red Hat support">
</p>

<p align="center">
  <img src="https://img.shields.io/badge/C%2B%2B-11-blue.svg" alt="Language">
  <img src="https://img.shields.io/badge/license-MIT-blue.svg" alt="License">
  <img src="https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg" alt="Semantic-release">
  <a href="https://opengeode-slack-invite.herokuapp.com">
    <img src="https://opengeode-slack-invite.herokuapp.com/badge.svg" alt="Slack invite">
  </a>
  <a href="https://doi.org/10.5281/zenodo.3610370">
    <img src="https://zenodo.org/badge/DOI/10.5281/zenodo.3610370.svg" alt="DOI">
  </a>
</p>

---

## Introduction

OpenGeode-IO provides input and output formats for [OpenGeode] models and meshes.

[OpenGeode]: https://github.com/Geode-solutions/OpenGeode

## Documentation

To check out our live documentation, visit [docs.geode-solutions.com](https://docs.geode-solutions.com).

Installing OpenGeode-IO is done:

- either, by compiling the C++ source.
- or, by using pip command `pip install OpenGeode-IO` and add `import opengeode_io` in your Python script.

## Questions

For questions and support please use the official [slack](https://opengeode-slack-invite.herokuapp.com) and go to the channel #io. The issue list of this repository is exclusively for bug reports and feature requests.

## Changelog

Detailed changes for each release are documented in the [release notes](https://github.com/Geode-solutions/OpenGeode-IO/releases).

## License

[MIT](https://opensource.org/licenses/MIT)

Copyright (c) 2019 - 2024, Geode-solutions
